@@ -1,3 +1,10 @@
+# --------------------------------------------------------
+# Octree-based Sparse Convolutional Neural Networks
+# Copyright (c) 2022 Peng-Shuai Wang <wangps@hotmail.com>
+# Licensed under The MIT License [see LICENSE for details]
+# Written by Peng-Shuai Wang
+# --------------------------------------------------------
+
 from .octree2vox import octree2voxel, Octree2Voxel
 from .octree2col import octree2col, col2octree
 from .octree_pad import octree_pad, octree_depad
@@ -8,9 +15,11 @@ from .octree_pool import (octree_max_pool, OctreeMaxPool,
                           octree_max_unpool, OctreeMaxUnpool,
                           octree_global_pool, OctreeGlobalPool)
 from .octree_conv import OctreeConv, OctreeDeconv
+from .octree_dwconv import OctreeDWConv
 from .octree_norm import OctreeInstanceNorm, OctreeBatchNorm
 from .octree_drop import OctreeDropPath
 
+
 __all__ = [
     'octree2voxel',
     'octree2col', 'col2octree',
@@ -23,6 +32,7 @@ __all__ = [
     'OctreeMaxPool', 'OctreeMaxUnpool',
     'OctreeGlobalPool',
     'OctreeConv', 'OctreeDeconv',
+    'OctreeDWConv',
     'OctreeInterp', 'OctreeUpsample',
     'OctreeInstanceNorm', 'OctreeBatchNorm',
     'OctreeDropPath',
